@@ -1,14 +1,11 @@
-from .conf import get_setting
-
-__title__ = 'tld.exceptions'
-__author__ = 'Artur Barseghyan'
-__copyright__ = '2013-2018 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__author__ = "Artur Barseghyan"
+__copyright__ = "2013-2023 Artur Barseghyan"
+__license__ = "MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-or-later"
 __all__ = (
-    'TldBadUrl',
-    'TldDomainNotFound',
-    'TldImproperlyConfigured',
-    'TldIOError',
+    "TldBadUrl",
+    "TldDomainNotFound",
+    "TldImproperlyConfigured",
+    "TldIOError",
 )
 
 
@@ -18,13 +15,6 @@ class TldIOError(IOError):
     Supposed to be thrown when problems with reading/writing occur.
     """
 
-    def __init__(self, msg=None):
-        tld_names_local_path = get_setting('NAMES_LOCAL_PATH')
-        if msg is None:
-            msg = "Can't read from or write to the %s " \
-                  "file!" % tld_names_local_path
-        super(TldIOError, self).__init__(msg)
-
 
 class TldDomainNotFound(ValueError):
     """TldDomainNotFound.
@@ -56,11 +46,3 @@ class TldImproperlyConfigured(Exception):
     is when user tries to use `get_tld` function with both `search_public` and
     `search_private` set to False.
     """
-
-    def __init__(self, msg=None):
-        if msg is None:
-            msg = "Improperly configured."
-        else:
-            msg = "Improperly configured. %s" % msg
-
-        super(TldImproperlyConfigured, self).__init__(msg)
